@@ -1,12 +1,18 @@
 ######
-gbp <- function(x, w, covariates, mean.PriorDist, model, intercept, Alpha, n.IS, trial.scale) UseMethod("gbp")
+gbp <- function(x, w, covariates, mean.PriorDist, model, intercept, Alpha, n.IS, trial.scale, normal.CI) UseMethod("gbp")
 ######
 gbp.default <- function(x, w, covariates, mean.PriorDist, model = "gaussian", 
                         intercept = TRUE, Alpha = 0.95, 
-                        n.IS = 0, trial.scale = 2.5) {
+                        n.IS = 0, trial.scale = 2.5, normal.CI = FALSE) {
+
+  ##input checks
+  if((abs(max(x) - min(x)) == 0) & (abs(max(w) - min(w)) == 0) & missing(mean.PriorDist))
+    stop("Groups have identical data. This program can not yet give reliable results for this data.")
+  
+  
 ######
   res <- switch(model, 
-       gaussian = gr(x, w, X = covariates, mu = mean.PriorDist, Alpha = Alpha, intercept = intercept), 
+       gaussian = gr(x, w, X = covariates, mu = mean.PriorDist, Alpha = Alpha, intercept = intercept, normal.CI = normal.CI), 
        binomial = br(x, w, X = covariates, prior.mean = mean.PriorDist, intercept = intercept, Alpha = Alpha,
                      n.IS = n.IS, trial.scale = trial.scale), 
        poisson = pr(x, w, X = covariates, prior.mean = mean.PriorDist, intercept = intercept, Alpha = Alpha))
