@@ -52,31 +52,27 @@ PRAlphaEst2ndLevelMeanKnown <- function(given, ini) {
   k <- length(n)
   a.ini <- ini$a.ini
 
-  PRDerivAlpha <- function(a) {
-    # The first and second order derivatives of log likelihood with respect to alpha
+  PRLogLikKn <- function (a) { 
     zam <- z + exp(-a) * mu0
     am <- exp(-a) * mu0
-
-    const1 <- ((digamma(zam) -  digamma(am) + n / (exp(-a) + n) - log(1 + n * exp(a))) * mu0
-               - z / (exp(-a) + n))
-    const3 <- (const1 + z * exp(-a) / (exp(-a) + n)^2 + mu0 * n / (n + exp(-a)) 
-               - n * am / (exp(-a) + n)^2 + am * mu0 * (trigamma(zam) - trigamma(am)))
-
-    out <- c(1 - exp(-a) * sum(const1), exp(-a) * sum(const3))
-    out
+    if (any(c(am, zam) <= 0)) {
+      print("The components of lgamma should be positive")
+      stop()
+    } else {
+      sum(dnbinom(z, size = am, prob = exp(-a) / (exp(-a) + n), log = T))
+    }
   }
 
-  dif <- 1
-  eps <- 0.0001
-  while (abs(dif) > eps) { 
-    out1 <- PRDerivAlpha(a.ini)
-    score <- out1[1]
-    hessian <- out1[2]
-    dif <- score / hessian
-    a.ini <- a.ini - dif
+  PostAlpha <- function(a) {
+    a + PRLogLikKn(a)
   }
 
-  list(a.new = a.ini, a.var = - 1/ hessian)
+  a.temp <- optim(a.ini, PostAlpha, control = list(fnscale = -1), method= "L-BFGS-B",
+                  hessian = TRUE,  lower = -Inf, upper = Inf)
+  a.new <- a.temp$par
+  a.hess <- a.temp$hessian
+
+  list(a.new = a.ini, a.var = - 1/ a.hess)
 }
 
 PRAlphaBetaEst2ndLevelMeanUnknown <- function(given, ini) {
